// ---------------------------------------------------------------------------
// kitHUD.cs -- Version 1.3 -- December 9, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Display your repair kit status in a small HUD
// VERY useful if you use auto_repair_kit.cs
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\kitHUD.cs", "1.3", "Lorne Laliberte", "Dec 9, 2000");

include("writer\\event.cs");
include("writer\\inventory.cs");
include("writer\\item_events.cs");
include("writer\\save.cs");
include("writer\\weapon_switch.cs");
include("writer\\whud.cs");
include("writer\\you_died.cs");
include("writer\\you_respawned.cs");
include("writer\\you_spawned.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_kitHUD.cs file

    // Screen coordinates for kitHUD
    $kitHUD::X = "100%";
    $kitHUD::Y = "48";

    // Make the kitHUD background transparent
    $kitHUD::transparent = "true";

    // Show kitHUD by default
    $kitHUD::visible = "true";

    // Toggle kitHUD on/off
    //bind(keyboard0, make, alt, "whatever", TO, "kitHUD::toggle();");
    //bind(keyboard0, break, alt, "whatever", TO, "", kitHUD::toggle_break);

// ---------------------------------------------------------------------------

WriterPrefs::load("kitHUD");

function kitHUD::toggle()
{
    if($kitHUD::visible = !$kitHUD::visible)
        wHUD::show(kitHUD);
    else
        wHUD::hide(kitHUD);
}

// todo:
// provide canned set of bitmaps, maybe the smaller ones like ZaDar would like too,
// and then a text option, and make the M_repair.bmp an optional prefix (set with flag)

function kitHUD::setup()
{

    if($kitHUD::transparent)
    {
        $kitHUD::width = 46;
        $kitHUD::height = 13;
        $kitHUD::message[kit]  = "<B0,0:writer\\kitHUD\\kit.bmp>";
        $kitHUD::message[auto] = "<B0,0:writer\\kitHUD\\auto.bmp>";
        $kitHUD::message[next] = "<B0,0:writer\\kitHUD\\next.bmp>";
        $kitHUD::message[none] = "<B0,0:writer\\kitHUD\\none.bmp>";
        $kitHUD::message[wait] = "<B0,0:writer\\kitHUD\\wait.bmp>";
        $kitHUD::message[go]   = "<B0,0:writer\\kitHUD\\go.bmp>";
        $kitHUD::message[dead] = "<B0,0:writer\\kitHUD\\dead.bmp>";
    }
    else
    {
        $kitHUD::width = 54;
        $kitHUD::height = 13;
        $kitHUD::message[kit]  = "<B3,5:M_repair.bmp><f2>KIT";
        $kitHUD::message[auto] = "<B3,5:M_repair.bmp><f1>Auto";
        $kitHUD::message[next] = "<B3,5:M_repair.bmp><f1>Next";
        $kitHUD::message[none] = "<B3,5:M_repair.bmp><f0>None";
        $kitHUD::message[wait] = "<B3,5:M_repair.bmp><f1>Wait";
        $kitHUD::message[go]   = "<B3,5:M_repair.bmp><f2> GO!";
        $kitHUD::message[dead] = "<B3,5:M_repair.bmp><f0>Dead";
    }
}


function kitHUD::message()
{
    if(getItemCount("Repair Kit"))
        return $kitHUD::message[kit];
    else if($AutoRepairKit::Override)
        return $kitHUD::message[auto];
    else if($AutoRepairKit::useNext)
        return $kitHUD::message[next];
    else
        return $kitHUD::message[none];
}


function kitHUD::NoKitMessage()
{
    if($AutoRepairKit::Override)
        return $kitHUD::message[auto];
    else if($AutoRepairKit::useNext)
        return $kitHUD::message[next];
    else
        return $kitHUD::message[none];
}


function kitHUD::onUsed(%itemtype, %itemname)
{
    if(%itemtype == $Inv::Repair_Kit)
    {
        if(!$kitHUD::fullHealthBuying)
            kitHUD::nokit();
    }
    return;
}


function kitHUD::onBuy(%itemtype, %itemname)
{
    if(%itemtype == $Inv::Repair_Kit)
    {
        if($Station::AtStation && !$kitHUD::fullHealthBuying)
            kitHUD::default();
    }
    return;
}

function kitHUD::onSell(%itemtype, %itemname)
{
    if(%itemtype == $Inv::Repair_Kit)
    {
        if($Station::AtStation)
            kitHUD::nokit();
    }
    return;
}


function kitHUD::onDropped(%itemtype, %itemname)
{
    if(%itemtype == $Inv::Repair_Kit)
            kitHUD::nokit();
    return;
}


function kitHUD::update()
{
    wHUD::update(kitHUD, kitHUD::message());
    return;
}

function kitHUD::noKit()
{
    wHUD::update(kitHUD, kitHUD::NoKitMessage());
    return;
}

function kitHUD::default()
{
    wHUD::update(kitHUD, $kitHUD::message[kit]);
    return;
}


function kitHUD::onFullHealthBuying()
{
    $kitHUD::fullHealthBuying = true;
    wHUD::update(kitHUD, $kitHUD::message[wait]);
    return;
}

function kitHUD::onFullHealthBought()
{
    $kitHUD::fullHealthBuying = false;
    wHUD::update(kitHUD, $kitHUD::message[go]);
    return;
}


function kitHUD::onYouDied()
{
    wHUD::update(kitHUD, $kitHUD::message[dead]);
    return;
}


function kitHUD::onYouSpawned()
{
    kitHUD::setup();

    // Build kitHUD on first weapon switch, after playGui exists
    if(!wHUD::exists(kitHUD))
        wHUD::makeMoveable(1, 1, 0, kitHUD, $kitHUD::x, $kitHUD::y, $kitHUD::width, $kitHUD::height, $kitHUD::transparent, $kitHUD::visible, kitHUD::message());
    else
        wHUD::show(kitHUD);

    return;
}


function kitHUD::relocate()
{
    kitHUD::setup();
    wHUD::makeMoveable(1, 1, 0, kitHUD, $kitHUD::x, $kitHUD::y, $kitHUD::width, $kitHUD::height, $kitHUD::transparent, $kitHUD::visible, kitHUD::message());
    return;
}


function onHudMove_kitHUD(%x, %y, %width, %height)
{
    $kitHUD::x = %x;
    $kitHUD::y = %y;
    $kitHUD::width = %width;
    wHUD::make(kitHUD, $kitHUD::x, $kitHUD::y, $kitHUD::width, $kitHUD::height, $kitHUD::transparent, 1, kitHUD::message());
    return;
}


function kitHUD::save()
{
    AddExportText("    // Screen coordinates for kitHUD");
    ExportSetting("    $kitHUD::X", "100%");
    ExportSetting("    $kitHUD::Y", "48");
    AddExportText("");
    AddExportText("    // Make the kitHUD background transparent");
    ExportSetting("    $kitHUD::transparent", true);
    AddExportText("");
    AddExportText("    // Show kitHUD by default");
    ExportSetting("    $kitHUD::visible", true);
    AddExportText("");
    AddExportText("    // Toggle kitHUD on/off");

    ExportBind("kitHUD::toggle();", "//bind(keyboard0, make, alt, \"whatever\", TO, \"kitHUD::toggle();\");");
    ExportBind("kitHUD::toggle_break", "//bind(keyboard0, break, alt, \"whatever\", TO, \"\", kitHUD::toggle_break);");
}

WriterPrefs::save("kitHUD");

function kitHUD::init()
{
    needs("writer\\kitHUD.cs", "writer\\event.cs 2.7",
                               "writer\\item_events.cs 2.12",
                               "writer\\inventory.cs 3.3",
                               "writer\\save.cs 2.3",
                               "writer\\weapon_switch.cs 2.5",
                               "writer\\whud.cs 1.2",
                               "writer\\you_died.cs 1.6",
                               "writer\\you_respawned.cs 1.2",
                               "writer\\you_spawned.cs 1.1");

    wants("writer\\kitHUD.cs", "writer\\auto_repair_kit.cs 3.15");

    Event::Attach(eventConnected, "kitHUD::default();");
    Event::Attach(eventChangeMission, "kitHUD::default();");
    Event::Attach(eventRepairKitFound, "kitHUD::default();");
    Event::Attach(eventYouRespawned, "kitHUD::default();");

    Event::Attach(eventAutoRepairKitToggled, "kitHUD::update();");
    Event::Attach(eventExitStation, "kitHUD::update();");
    Event::Attach(eventResupplyComplete, "kitHUD::update();");
    Event::Attach(eventRepairKitPressed, "kitHUD::update();");

    Event::Attach(eventFullHealthBuying, "kitHUD::onFullHealthBuying();");
    Event::Attach(eventFullHealthBought, "kitHUD::onFullHealthBought();");

    Event::Attach(eventBuy, kitHUD::onBuy);
    Event::Attach(eventSell, kitHUD::onSell);
    Event::Attach(eventUsed, kitHUD::onUsed);
    Event::Attach(eventDropped, kitHUD::onDropped);
    Event::Attach(eventYouDied, "kitHUD::onYouDied();");

    Event::Attach(eventYouSpawned, "kitHUD::onYouSpawned();");
    Event::Attach(eventScreenModeChanged, "kitHUD::relocate();");
    Event::Attach(eventScreenSizeChanged, "kitHUD::relocate();");
    Event::Attach(wHudMove_kitHUD, onHudMove_kitHUD);
    Event::Attach(wHudSave_kitHUD, "WriterPrefs::save(\"kitHUD\");");
}
Event::Attach(writerInit, "kitHUD::init();");

if(!$UsingWriterLoader) kitHUD::init();
